@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::ChangeStats::Git::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.1.1';
+  $Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.1.2';
 }
 # ABSTRACT: add code churn statistics to the changelog
 
@@ -44,17 +44,19 @@ has group => (
 sub munge_files {
   my ($self) = @_;
 
-  my @output = $self->repo->run( 'log', '--stat', 'releases..master' );
+  my @output = $self->repo->run( 'diff', '--stat', 'releases..master' );
 
   # actually, only the last line is interesting
   my $stats = "code churn: " . $output[-1];
   $stats =~ s/\s+/ /g;
 
-  my ( $next ) = reverse $self->zilla->changes->releases;
+  my $changelog = $self->zilla->changelog;
+
+  my ( $next ) = reverse $changelog->releases;
 
   $next->add_changes( { group => $self->group  }, $stats );
 
-  $self->zilla->save_changelog;
+  $self->zilla->save_changelog($changelog);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -71,7 +73,7 @@ Dist::Zilla::Plugin::ChangeStats::Git - add code churn statistics to the changel
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
